package FBP::StaticText;

use Moose;

our $VERSION = '0.02';

extends 'FBP::Window';

1;
